/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Boreas SDK, Version 7.0                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

import java.net.InetAddress;
import java.net.UnknownHostException;

/* IP Dataports Configuration */
public class ANPacket202
{
	public static final int LENGTH = 30;

	public static final String[] PORT_MODE_STRINGS = new String[] {
			"None",
			"Reserved",
			"TCP Server",
			"TCP Client",
			"UDP"
	};
	public static final int MODE_NONE = 0;
	public static final int MODE_TCP_SERVER = 2;
	public static final int MODE_TCP_CLIENT = 3;
	public static final int MODE_UDP = 4;

	public Ports dataPorts[];

	public ANPacket202()
	{
	}

	public ANPacket202(ANPacket packet)
	{
		dataPorts = new Ports[4];
		for (int i = 0; i < 4; ++i)
		{
			dataPorts[i] = new Ports();
			dataPorts[i].readNew(packet.data, 2 + i * 7);
		}
	}

	public ANPacket toANPacket() throws IndexOutOfBoundsException
	{
		if (dataPorts != null)
		{
			if (dataPorts[0] == null || dataPorts[1] == null || dataPorts[2] == null || dataPorts[3] == null)
			{
				throw new IndexOutOfBoundsException();
			}
			if (!dataPorts[0].valid() ||
				!dataPorts[1].valid() ||
				!dataPorts[2].valid() ||
				!dataPorts[3].valid())
			{
				throw new IndexOutOfBoundsException();
			}

			ANPacket packet = new ANPacket(LENGTH, ANPacket.PACKET_ID_IP_DATAPORTS_CONFIGURATION);
			for (int i = 0; i < 4; ++i)
			{
				dataPorts[i].writeNew(packet.data, 2 + i * 7);
			}

			return packet;
		}

		return null;
	}

	public static String modeToString(int mode)
	{
		if (mode < PORT_MODE_STRINGS.length)
		{
			return PORT_MODE_STRINGS[mode];
		}
		else
		{
			return "Unknown Mode";
		}
	}

	public class Ports
	{
		public InetAddress ipAddress;
		public int tcpUdpPort;
		public int mode;

		void readNew(byte data[], int offset)
		{
			try
			{
				ipAddress = ANPacket11.bytestoInetAddress(data, offset);	// 4 bytes
			}
			catch (UnknownHostException e)
			{
				e.printStackTrace();
			}
			tcpUdpPort = TypeConversion.bytesToUInt16(data, offset + 4);	// 2 bytes
			mode = data[offset + 6] & 0xFF;	// 1 bytes
		}

		void writeNew(byte data[], int offset)
		{
			ANPacket11.iNetAddresstoBytes(ipAddress, data, offset);
			TypeConversion.int16ToBytes(data, offset + 4, tcpUdpPort);
			data[offset + 6] = (byte) (mode & 0xFF);
		}

		boolean valid()
		{
			if ((tcpUdpPort <= 0) || (tcpUdpPort >= 0xFFFF))	return false;
			if ((mode != MODE_NONE) && (mode != MODE_TCP_SERVER) &&
				(mode != MODE_TCP_CLIENT) && (mode != MODE_UDP)) return false;

			return true;
		}
	}
}
