/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Boreas SDK, Version 7.0                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* CAN Configuration */
public class ANPacket203
{
	public static final int LENGTH = 11;

	public static final String[] CAN_PROTOCOL_STRINGS = new String[] { "CANopen" };

	public int permanent;
	public boolean enabled;
	public long baudrate;
	public int canProtocol;

	public ANPacket203()
	{
	}

	public ANPacket203(ANPacket packet)
	{
		permanent	= packet.data[0] & 0xFF;
		enabled		= (packet.data[1] & 0xFF) != 0;
		baudrate	= TypeConversion.bytesToUInt32(packet.data, 2);
		canProtocol	= packet.data[6] & 0xFF;
	}

	public ANPacket toANPacket()
	{
		ANPacket packet = new ANPacket(LENGTH, ANPacket.PACKET_ID_CAN_CONFIGURATION);
		packet.data[0] = (byte) (permanent & 0xFF);
		packet.data[1] = (byte) (enabled ? 1 : 0);
		TypeConversion.uint32ToBytes(packet.data, 2, baudrate);
		packet.data[6] = (byte) (canProtocol & 0xFF);
		return packet;
	}

	public static String canProtocolToString(int protocol)
	{
		if (protocol < CAN_PROTOCOL_STRINGS.length)
		{
			return CAN_PROTOCOL_STRINGS[protocol];
		}
		else
		{
			return "Unknown Protocol";
		}
	}

	public String canProtocolToString()
	{
		return canProtocolToString(canProtocol);
	}
}
