/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Boreas SDK, Version 7.0                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

import java.nio.charset.StandardCharsets;

/* Device Name */
public class ANPacket204
{
	public static final int LENGTH = 65;
	public static final int DEVICE_NAME_LENGTH = 32;

	public boolean permanent;
	private byte[] deviceName;

	public ANPacket204()
	{
		permanent = true;
		deviceName = new byte[DEVICE_NAME_LENGTH];
	}

	public ANPacket204(ANPacket packet)
	{
		if (packet.data.length == LENGTH)
		{
			permanent = packet.data[0] != 0;
			deviceName = new byte[DEVICE_NAME_LENGTH];

			for (int i = 0; i < DEVICE_NAME_LENGTH; i++)
			{
				deviceName[i] = packet.data[i + 1];
			}
		}
	}

	public ANPacket toANPacket()
	{
		ANPacket packet = new ANPacket(LENGTH, ANPacket.PACKET_ID_DEVICE_NAME);
		packet.data[0] = (byte) (permanent ? 1 : 0);

		for (int i = 0; i < DEVICE_NAME_LENGTH; i++)
		{
			packet.data[i + 1] = deviceName[i];
		}

		return packet;
	}

	public boolean setDeviceName(String name)
	{
		byte[] newName = name.getBytes(StandardCharsets.UTF_8);

		if (newName.length <= DEVICE_NAME_LENGTH)
		{
			deviceName = new byte[DEVICE_NAME_LENGTH];
			for (int i = 0; i < newName.length; i++)
			{
				deviceName[i] = newName[i];
			}
			return true;
		}
		else
		{
			return false;
		}
	}

	public String getDeviceName()
	{
		return new String(deviceName, StandardCharsets.UTF_8);
	}
}
