/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Boreas SDK, Version 7.0                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* Raw DVL Data */
public class ANPacket70
{
	public static final int LENGTH = 60;

	public long unixTimeStamp;
	public long microseconds;
	public Boolean bottomVelocityValid;
	public Boolean waterVelocityValid;
	public Boolean temperatureValid;
	public Boolean depthValid;
	public Boolean altitudeValid;
	public Boolean bottomVelocityStandardDeviationValid;
	public float[] bottomVelocity;
	public float bottomVelocityStandardDeviation;
	public float[] waterVelocity;
	public float waterVelocityStandardDeviation;
	public float waterVelocityLayerDepth;
	public float depth;
	public float altitude;
	public float temperature;
	
	public ANPacket70(ANPacket packet)
	{
		unixTimeStamp = TypeConversion.bytesToUInt32(packet.data, 0);
		microseconds = TypeConversion.bytesToUInt32(packet.data, 4);
		bottomVelocityValid = (packet.data[8] & 0x01) != 0;
		waterVelocityValid = (packet.data[8] & 0x02) != 0;
		temperatureValid = (packet.data[8] & 0x04) != 0;
		depthValid = (packet.data[8] & 0x08) != 0;
		altitudeValid = (packet.data[8] & 0x10) != 0;
		bottomVelocityStandardDeviationValid = (packet.data[8] & 0x20) != 0;
		bottomVelocity = new float[3];
		bottomVelocity[0] = TypeConversion.bytesToFloat(packet.data, 12);
		bottomVelocity[1] = TypeConversion.bytesToFloat(packet.data, 16);
		bottomVelocity[2] = TypeConversion.bytesToFloat(packet.data, 20);
		bottomVelocityStandardDeviation = TypeConversion.bytesToFloat(packet.data, 24);
		waterVelocity = new float[3];
		waterVelocity[0] = TypeConversion.bytesToFloat(packet.data, 28);
		waterVelocity[1] = TypeConversion.bytesToFloat(packet.data, 32);
		waterVelocity[2] = TypeConversion.bytesToFloat(packet.data, 36);
		waterVelocityStandardDeviation = TypeConversion.bytesToFloat(packet.data, 40);
		waterVelocityLayerDepth = TypeConversion.bytesToFloat(packet.data, 44);
		depth = TypeConversion.bytesToFloat(packet.data, 48);
		altitude = TypeConversion.bytesToFloat(packet.data, 52);
		temperature = TypeConversion.bytesToFloat(packet.data, 56);
	}
}
