/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Boreas SDK, Version 7.0                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* North Seeking Status */
public class ANPacket71
{
	public static final int LENGTH = 28;

	public Boolean northSeekingInitialised;
	public Boolean positionNotReady;
	public Boolean excessiveRoll;
	public Boolean excessivePitch;
	public Boolean excessiveMovement;
	public Boolean changeLatitude;
	public Boolean changeLeverArm;
	public Boolean invalidLatitude;
	public Boolean method;
	public int[] quadrantCount;
	public float currentRotationAngle;
	public int currentQuadrant;
	public float[] biasEstimate;
	public float biasEstimateError;
	
	public ANPacket71(ANPacket packet)
	{
		northSeekingInitialised = (packet.data[0] & 0x01) != 0;
		positionNotReady = (packet.data[0] & 0x02) != 0;
		excessiveRoll = (packet.data[0] & 0x04) != 0;
		excessivePitch = (packet.data[0] & 0x08) != 0;
		excessiveMovement = (packet.data[0] & 0x10) != 0;
		changeLatitude = (packet.data[0] & 0x20) != 0;
		changeLeverArm = (packet.data[0] & 0x40) != 0;
		invalidLatitude = (packet.data[0] & 0x80) !=0;
		method = (packet.data[2] & 0x01) !=0; 
		quadrantCount = new int[4];
		quadrantCount[0] = packet.data[4] & 0xFF;
		quadrantCount[1] = packet.data[5] & 0xFF;
		quadrantCount[2] = packet.data[6] & 0xFF;
		quadrantCount[3] = packet.data[7] & 0xFF;
		currentRotationAngle = TypeConversion.bytesToFloat(packet.data, 8);
		biasEstimate = new float[3];
		biasEstimate[0] = TypeConversion.bytesToFloat(packet.data, 12);
		biasEstimate[1] = TypeConversion.bytesToFloat(packet.data, 16);
		biasEstimate[2] = TypeConversion.bytesToFloat(packet.data, 20);
		biasEstimateError = TypeConversion.bytesToFloat(packet.data, 24);
		if(Math.abs(currentRotationAngle) < Math.PI / 4) currentQuadrant = 0;
		else if(Math.abs(currentRotationAngle) > 3 * Math.PI / 4) currentQuadrant = 2;
		else if(currentRotationAngle > 0) currentQuadrant = 1;
		else currentQuadrant = 3;
	}
}
